pub struct EncodedContent {
pub type: Option<ContentTypeId>,
pub parameters: HashMap<String, String>,
pub fallback: Option<String>,
pub compression: Option<i32>,
pub content: Vec<u8>,
}Expand description
EncodedContent bundles the content with metadata identifying its type and parameters required for correct decoding and presentation of the content.
Fields
type: Option<ContentTypeId>content type identifier used to match the payload with the correct decoding machinery
parameters: HashMap<String, String>optional encoding parameters required to correctly decode the content
fallback: Option<String>optional fallback description of the content that can be used in case the client cannot decode or render the content
compression: Option<i32>optional compression; the value indicates algorithm used to compress the encoded content bytes
content: Vec<u8>encoded content itself
Implementations
Sourceimpl EncodedContent
impl EncodedContent
Sourcepub fn fallback(&self) -> &str
pub fn fallback(&self) -> &str
Returns the value of fallback, or the default value if fallback is unset.
Sourcepub fn compression(&self) -> Compression
pub fn compression(&self) -> Compression
Returns the enum value of compression, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_compression(&mut self, value: Compression)
pub fn set_compression(&mut self, value: Compression)
Sets compression to the provided enum value.