pub struct FrameAction {
pub signature: Option<Signature>,
pub signed_public_key_bundle: Option<SignedPublicKeyBundle>,
pub action_body: Vec<u8>,
pub installation_signature: Vec<u8>,
pub installation_id: Vec<u8>,
pub inbox_id: String,
}Expand description
The outer payload that will be sent as the messageBytes in the
trusted_data part of the Frames message
Fields
signature: Option<Signature>👎Deprecated
signed_public_key_bundle: Option<SignedPublicKeyBundle>👎Deprecated
The SignedPublicKeyBundle of the signer, used to link the XMTP signature with a blockchain account through a chain of signatures.
action_body: Vec<u8>Serialized FrameActionBody message, so that the signature verification can happen on a byte-perfect representation of the message
installation_signature: Vec<u8>The installation signature
installation_id: Vec<u8>The public installation id used to sign.
inbox_id: StringThe inbox id of the installation used to sign.