pub struct FrameActionBody {
pub frame_url: String,
pub button_index: i32,
pub timestamp: u64,
pub opaque_conversation_identifier: String,
pub unix_timestamp: u32,
pub input_text: String,
pub state: String,
pub address: String,
pub transaction_id: String,
}Expand description
The message that will be signed by the Client and returned inside the
action_body field of the FrameAction message
Fields
frame_url: StringThe URL of the frame that was clicked
May be different from post_url
The 1-indexed button that was clicked
timestamp: u64👎Deprecated
Timestamp of the click in milliseconds since the epoch
opaque_conversation_identifier: StringA unique identifier for the conversation, not tied to anything on the network. Will not match the topic or conversation_id
unix_timestamp: u32Unix timestamp
input_text: StringInput text from a text input field
state: StringA state serialized to a string (for example via JSON.stringify()). Maximum 4096 bytes.
address: StringA 0x wallet address
transaction_id: StringA hash from a transaction