pub struct MessageV2 {
pub header_bytes: Vec<u8>,
pub ciphertext: Option<Ciphertext>,
pub sender_hmac: Option<Vec<u8>>,
pub should_push: Option<bool>,
}Expand description
Message combines the encoded header with the encrypted payload.
Fields
header_bytes: Vec<u8>encapsulates encoded MessageHeaderV2
ciphertext: Option<Ciphertext>Ciphertext.payload MUST contain encrypted SignedContent
sender_hmac: Option<Vec<u8>>HMAC of the message ciphertext, with the HMAC key derived from the topic key
should_push: Option<bool>Flag indicating whether the message should be pushed from a notification server
Implementations
Sourceimpl MessageV2
impl MessageV2
Sourcepub fn sender_hmac(&self) -> &[u8] ⓘ
pub fn sender_hmac(&self) -> &[u8] ⓘ
Returns the value of sender_hmac, or the default value if sender_hmac is unset.
Sourcepub fn should_push(&self) -> bool
pub fn should_push(&self) -> bool
Returns the value of should_push, or the default value if should_push is unset.