pub struct SignedContent {
pub payload: Vec<u8>,
pub sender: Option<SignedPublicKeyBundle>,
pub signature: Option<Signature>,
}Expand description
SignedContent attaches a signature to EncodedContent.
Fields
payload: Vec<u8>MUST contain EncodedContent
sender: Option<SignedPublicKeyBundle>signature: Option<Signature>MUST be a signature of a concatenation of the message header bytes and the payload bytes, signed by the sender’s pre-key.